@@ -18,16 +18,15 @@ has 'input_files'       => ( is => 'ro', isa => 'ArrayRef' , required => 1);
 
 # Parameters for preprocessing
 has 'min_length'	   => ( is => 'ro', isa => 'Num', default => 51);
-has 'quality_filter'   => ( is => 'ro', isa => 'Num', default => 3);
 has 'quality_trim'	   => ( is => 'ro', isa => 'Num', default => 3);
+has 'pe_mode'		   => ( is => 'ro', isa => 'Num', default => 2); #We set default to 2 as the pipeline will almost always send in an interleaved fastq file
 
 # Parameters for indexing and correction
 has 'algorithm'	        => ( is => 'ro', isa => 'Str',   default => 'ropebwt'); # BWT construction algorithm: sais or ropebwt
 has 'threads'	        => ( is => 'ro', isa => 'Num',   default => 1); # Use this many threads for computation
-has 'disk'				=> ( is => 'ro', isa => 'Num', default => 1000000); # suffix array
 has 'kmer_threshold'	=> ( is => 'ro', isa => 'Num',   default=> 5); # Attempt to correct kmers that are seen less than this many times
-has 'kmer_length'	    => ( is => 'ro', isa => 'Num',   default=> 31); # TODO: Calculate sensible default value
-has 'output_filename'   => ( is => 'rw', isa => 'Str',  default  => '_sga_error_corrected.fastq' );
+has 'kmer_length'	    => ( is => 'ro', isa => 'Num',   default=> 41); 
+has 'output_filename'   => ( is => 'rw', isa => 'Str',  default  => '_sga_error_corrected.fastq.gz' ); #We always zip the results 
 has 'output_directory'  => ( is => 'rw', isa => 'Str', lazy => 1, builder => '_build_output_directory' ); # Default to cwd
 has 'sga_exec'          => ( is => 'rw', isa => 'Str',   required => 1 );
 has 'debug'             => ( is => 'ro', isa => 'Bool',  default => 0);
@@ -62,8 +61,9 @@ sub run {
     # SGA preprocess
     my $sga_preprocessor     = Bio::AssemblyImprovement::Assemble::SGA::PreprocessReads->new(
             input_files      => $self->input_files,
+            pe_mode			 => $self->pe_mode,
             min_length	     => $self->min_length,
-            quality_filter	 => $self->quality_filter,
+            pe_mode	  		 => $self->pe_mode,
             quality_trim	 => $self->quality_trim,
             output_directory => $self->output_directory,
             sga_exec         => $self->sga_exec,
@@ -75,14 +75,11 @@ sub run {
 	# Move preprocessed file to this temporary directory
 	move ( $sga_preprocessor->_output_filename(), $self->_intermediate_file  );
 	
-
-	
 	# SGA error correction (on the results from above)
 	my $sga_error_corrector = Bio::AssemblyImprovement::Assemble::SGA::IndexAndCorrectReads->new(
       input_filename 		=> $self->_intermediate_file,
       algorithm      		=> $self->algorithm,
       threads        		=> $self->threads,
-      disk					=> $self->disk,
       kmer_threshold		=> $self->kmer_threshold,
       kmer_length	 		=> $self->kmer_length,
       sga_exec	     		=> $self->sga_exec,
@@ -92,13 +89,10 @@ sub run {
 	$sga_error_corrector->run();
 	
 	chdir($original_cwd);
-	
-	# Move the results file from temporary directory to the original cwd and zip it. 
-	move ( $sga_error_corrector->_output_filename, $self->_final_results_file);
-	$self->_zip_file(  $self->_final_results_file, $self->output_directory );
-	
 
-    
+	my $zipped_results = $self->_zip_file( $sga_error_corrector->_output_filename , $self->output_directory );
+	move ( $zipped_results, $self->_final_results_file);
+
     return $self;
 }
 
@@ -117,7 +111,7 @@ Bio::AssemblyImprovement::Assemble::SGA::Main - Run SGA preprocess and error cor
 
 =head1 VERSION
 
-version 1.131060
+version 1.131890
 
 =head1 SYNOPSIS
 
