@@ -14,7 +14,7 @@ with 'Bio::AssemblyImprovement::Util::UnzipFileIfNeededRole';
 has 'input_files'      => ( is => 'ro', isa => 'ArrayRef' , required => 1);
 has 'output_filename'  => ( is => 'rw', isa => 'Str', default  => '_sga_preprocessed.fastq' );
 has 'min_length'	   => ( is => 'ro', isa => 'Num', default => 66); # Change this to be the value of the minimum kmer length used by the assembler later on in the pipeline
-# has 'quality_filter'   => ( is => 'ro', isa => 'Num', default => 3); # Not going to do any filtering from now on. 1.3.2013
+has 'pe_mode'		   => ( is => 'ro', isa => 'Num', default => 2); #We set default to 2 as the pipeline will almost always send in an interleaved fastq file
 has 'quality_trim'	   => ( is => 'ro', isa => 'Num', default => 20); # Use a quality score of 20 by default
 has 'sga_exec'         => ( is => 'rw', isa => 'Str', required => 1 );
 has 'debug'            => ( is => 'ro', isa => 'Bool', default  => 0);
@@ -30,20 +30,21 @@ sub run {
     
     my $stdout_of_program = '';
     $stdout_of_program =  "> /dev/null 2>&1"  if($self->debug == 0);
+    
+    my $files_string = join (' ', @$prepared_input_files ); #Could be one shuffled file, or two files with forward and reverse reads 
 
     system(
         join(
             ' ',
             (
                 $self->sga_exec, 'preprocess',
-                '--pe-mode 1', # Input presented in two files with paired reads (forward and reverse)
-                #'--permute-ambiguous', # Randomly change ambiguous base calls - we would rather reads with ambiguous bases be thrown away
+                '--pe-mode', $self->pe_mode, 
+                #'--permute-ambiguous', # Do not randomly change ambiguous base calls - we would rather reads with ambiguous bases be thrown away
                 '--min-length', $self->min_length,
                 #'--quality-filter', $self->quality_filter,
                 '--quality-trim', $self->quality_trim,
                 '--out', $self->output_filename, 
-               	$prepared_input_files->[0],
-               	$prepared_input_files->[1],
+               	$files_string,
                 $stdout_of_program
             )
         )
@@ -87,7 +88,7 @@ Bio::AssemblyImprovement::Assemble::SGA::PreprocessReads - Preprocess reads befo
 
 =head1 VERSION
 
-version 1.131060
+version 1.131890
 
 =head1 SYNOPSIS
 
@@ -115,7 +116,7 @@ Unzip input files if needed
 
 =head2 run
 
-Run sga preprocess with -pe-mode 1 on the input data. 
+Run sga preprocess on the input data. 
 
 =head2 _output_filename
 
